@@ -373,7 +373,7 @@ class IWidget(IWidgetInterface, ABC):
 
         text = self._font.render(text, 1, color, bg_color)
         textpos = text.get_rect()
-        textpos.leftx = self._x
+        textpos.left = self._x
         textpos.centery = self._y + (self._h / 2)
         surface.blit(text, textpos)
 
@@ -394,7 +394,7 @@ class IWidget(IWidgetInterface, ABC):
 
         text = self._font.render(text, 1, color, bg_color)
         textpos = text.get_rect()
-        textpos.rightx = self._x + self._w - 1
+        textpos.right = self._x + self._w - 1
         textpos.centery = self._y + (self._h / 2)
         surface.blit(text, textpos)
 
